{% load meta %}

{% if meta %}
{% if meta.description %}{% meta 'description' meta.description %}{% endif %}
{% if meta.keywords %}{% meta_list 'keywords' meta.keywords %}{% endif %}
{% if meta.extra_props %}{% meta_extras meta.extra_props %}{% endif %}
{% if meta.extra_custom_props %}{% custom_meta_extras meta.extra_custom_props %}{% endif %}
{% if meta.use_og %}
{% if meta.title %}{% og_prop 'title' meta.title %}{% endif %}
{% if meta.url %}{% og_prop 'url' meta.url %}{% endif %}
{% if meta.description %}{% og_prop 'description' meta.description %}{% endif %}
{% if meta.image %}{% og_prop 'image' meta.image %}{% endif %}
{% if meta.object_type %}{% og_prop 'type' meta.object_type %}{% endif %}
{% if meta.site_name %}{% og_prop 'site_name'  meta.site_name %}{% endif %}
{% if meta.locale %}{% og_prop 'locale'  meta.locale%}{% endif %}
{% endif %}
{% if meta.use_twitter %}
{% if meta.title %}{% twitter_prop 'title' meta.title %}{% endif %}
{% if meta.url %}{% twitter_prop 'url' meta.url %}{% endif %}
{% if meta.description %}{% twitter_prop 'description' meta.description %}{% endif %}
{% if meta.image %}{% twitter_prop 'image' meta.image %}{% endif %}
{% if meta.twitter_site %}{% twitter_prop 'site' meta.twitter_site %}{% endif %}
{% if meta.twitter_creator %}{% twitter_prop 'creator' meta.twitter_creator %}{% endif %}
{% if meta.twitter_card %}{% twitter_prop 'card' meta.twitter_card %}{% endif %}
{% endif %}
{% if meta.use_facebook %}
{% if meta.facebook_app_id %}{% facebook_prop 'app_id' meta.facebook_app_id %}{% endif %}
{% endif %}
{% if meta.use_googleplus %}
{% if meta.title %}{% googleplus_prop 'name' meta.title %}{% endif %}
{% if meta.url %}{% googleplus_prop 'url' meta.url %}{% endif %}
{% if meta.description %}{% googleplus_prop 'description' meta.description %}{% endif %}
{% if meta.image %}{% googleplus_prop 'image' meta.image %}{% endif %}
{% endif %}
{% endif %}
